@@ -22,6 +22,7 @@ from .api_pb2 import (  # type: ignore
     ListEntitiesDateTimeResponse,
     ListEntitiesEventResponse,
     ListEntitiesFanResponse,
+    ListEntitiesInfraredResponse,
     ListEntitiesLightResponse,
     ListEntitiesLockResponse,
     ListEntitiesMediaPlayerResponse,
@@ -72,6 +73,7 @@ from .model import (
     EventInfo,
     FanInfo,
     FanState,
+    InfraredInfo,
     LightInfo,
     LightState,
     LockEntityState,
@@ -138,6 +140,7 @@ LIST_ENTITIES_SERVICES_RESPONSE_TYPES: dict[Any, type[EntityInfo] | None] = {
     ListEntitiesDateTimeResponse: DateTimeInfo,
     ListEntitiesEventResponse: EventInfo,
     ListEntitiesFanResponse: FanInfo,
+    ListEntitiesInfraredResponse: InfraredInfo,
     ListEntitiesLightResponse: LightInfo,
     ListEntitiesLockResponse: LockInfo,
     ListEntitiesMediaPlayerResponse: MediaPlayerInfo,
